# Test for semantic release and PyPI

[![PyPI version](https://badge.fury.io/py/semres-jerivas.svg)](https://pypi.org/project/semres-jerivas/)
[![Workflow status](https://github.com/jerivas/semres-jerivas/workflows/Test%20and%20release/badge.svg)](https://github.com/jerivas/semres-jerivas/actions?query=workflow%3A%22Test+and+release%22)

- Based on [semantic-release](https://github.com/semantic-release/semantic-release)
- Automatically produces PyPI releases following [semantic versioning](http://semver.org/)
- Supports Alpha, Beta, and RC releases on PyPI
- Testing and releasing completely automated and handled by GitHub actions
